=======
History
=======

1.0.0 (2024-08-08)
------------------

* Fix button customization in paged surveys.
* Add progress bar option to pages.
* Add option to pass a list to Page's constructor, in order to both have the current page number and an associated value.
* Add survey download button and file importer.
* Add "widget_key" to survey data to help restore survey data for displayed widgets.

0.1.0 (2023-03-23)
------------------

* First release.
